diff --git a/README.md b/README.md
index 2fde71e7..ed885110 100644
--- a/README.md
+++ b/README.md
@@ -5,7 +5,7 @@
**Requires at least:** 4.4
**Requires PHP:** 5.4
**Tested up to:** 6.4.1
-**Stable tag:** 1.6.23
+**Stable tag:** 1.6.24
**License:** GPLv2 or later
**License URI:** http://www.gnu.org/licenses/gpl-2.0.html
@@ -140,6 +140,11 @@ This same applies when you are creating your Header/Footer using this plugin.
## Changelog ##
+### 1.6.24 ###
+- Improvement: Compatibility with latest Elementor and Elementor Pro 3.19 version.
+- Fix: White Label - Astra's theme name does not change when Astra is white-labeled.
+- Fix: Navigation Menu - Language switcher flags not displaying when using Polylang plugin.
+
### 1.6.23 ###
- Fix: This update addressed a security bug. Props to WordPress Plugin Review Team and Plugin Vulnerabilities Team for reporting it to our team. Please make sure you are using the latest version on your website.
diff --git a/inc/class-hfe-settings-page.php b/inc/class-hfe-settings-page.php
index 95b7ce3e..040a1813 100644
--- a/inc/class-hfe-settings-page.php
+++ b/inc/class-hfe-settings-page.php
@@ -361,7 +361,7 @@ public function get_guide_html() {
-
+
@@ -508,12 +508,34 @@ public function get_about_html() {
$this->output_about_addons();
}
+ /**
+ * Function for Astra Pro white labels with defaults.
+ *
+ * @since 1.6.24
+ * @return array
+ */
+ protected function get_white_label() {
+ $white_labels = is_callable( 'Astra_Admin_Helper::get_admin_settings_option' ) ? \Astra_Admin_Helper::get_admin_settings_option( '_astra_ext_white_label', true ) : array();
+
+ $theme_name = ! empty( $white_labels['astra']['name'] ) ? $white_labels['astra']['name'] : 'Astra';
+
+ return array(
+ 'theme_name' => $theme_name,
+ 'description' => ! empty( $white_labels['astra']['description'] ) ? $white_labels['astra']['description'] : esc_html( sprintf( __( 'Powering over 1+ Million websites, %s is loved for the fast performance and ease of use it offers. It is suitable for all kinds of websites like blogs, portfolios, business, and WooCommerce stores.', 'header-footer-elementor' ), esc_html( $theme_name ) ) ),
+ 'theme_icon' => ! empty( $white_labels['astra']['icon'] ) ? $white_labels['astra']['icon'] : '',
+ 'author_url' => ! empty( $white_labels['astra']['author_url'] ) ? $white_labels['astra']['author_url'] : 'https://wpastra.com/',
+ );
+ }
+
/**
* Display the General Info section of About tab.
*
* @since 1.6.0
*/
protected function output_about_info() {
+
+ $white_labels = $this->get_white_label();
+
?>
@@ -527,7 +549,7 @@ protected function output_about_info() {
-
+
@@ -706,18 +728,20 @@ protected function get_plugin_data( $addon, $details, $all_plugins, $all_themes
*/
protected function get_bsf_plugins() {
+ $white_labels = $this->get_white_label();
+
$images_url = HFE_URL . 'assets/images/settings/';
return [
'astra' => [
- 'icon' => $images_url . 'plugin-astra.png',
+ 'icon' => ! empty( $white_labels['theme_icon'] ) ? $white_labels['theme_icon'] : $images_url . 'plugin-astra.png',
'type' => 'theme',
- 'name' => esc_html__( 'Astra Theme', 'header-footer-elementor' ),
- 'desc' => esc_html__( 'Powering over 1+ Million websites, Astra is loved for the fast performance and ease of use it offers. It is suitable for all kinds of websites like blogs, portfolios, business, and WooCommerce stores.', 'header-footer-elementor' ),
+ 'name' => $white_labels['theme_name'],
+ 'desc' => $white_labels['description'],
'wporg' => 'https://wordpress.org/themes/astra/',
'url' => 'https://downloads.wordpress.org/theme/astra.zip',
- 'siteurl' => 'https://wpastra.com/',
+ 'siteurl' => $white_labels['author_url'],
'pro' => false,
'slug' => 'astra',
],
diff --git a/inc/widgets-manager/widgets/class-navigation-menu.php b/inc/widgets-manager/widgets/class-navigation-menu.php
index f8ce92f0..3308f6ab 100644
--- a/inc/widgets-manager/widgets/class-navigation-menu.php
+++ b/inc/widgets-manager/widgets/class-navigation-menu.php
@@ -1931,8 +1931,6 @@ protected function render() {
add_filter( 'nav_menu_li_values', [ $this, 'handle_li_values' ] );
}
- $menu_html = wp_nav_menu( $args );
-
if ( 'flyout' === $settings['layout'] ) {
$this->add_render_attribute( 'hfe-flyout', 'class', 'hfe-flyout-wrapper' );
@@ -1953,7 +1951,7 @@ protected function render() {
@@ -2029,7 +2027,7 @@ protected function render() {
diff --git a/header-footer-elementor.php b/header-footer-elementor.php
index 0611bec3..9f4cf0f2 100644
--- a/header-footer-elementor.php
+++ b/header-footer-elementor.php
@@ -7,14 +7,14 @@
* Author URI: https://www.brainstormforce.com/
* Text Domain: header-footer-elementor
* Domain Path: /languages
* Version: 1.6.23
* Elementor tested up to: 3.18
* Elementor Pro tested up to: 3.18
*
* @package header-footer-elementor
*/
-define( 'HFE_VER', '1.6.23' );
+define( 'HFE_VER', '1.6.24' );
define( 'HFE_FILE', __FILE__ );
define( 'HFE_DIR', plugin_dir_path( __FILE__ ) );
define( 'HFE_URL', plugins_url( '/', __FILE__ ) );
@@ -7,14 +7,14 @@
* Text Domain: header-footer-elementor
* Domain Path: /languages
- * Version: 1.6.23
- * Elementor tested up to: 3.18
- * Elementor Pro tested up to: 3.18
+ * Version: 1.6.24
+ * Elementor tested up to: 3.19
+ * Elementor Pro tested up to: 3.19
*
* @package header-footer-elementor